#!/usr/bin/env python

"""
Test file-based storage.

Copyright (C) 2017 Paul Boddie <paul@boddie.org.uk>

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation; either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
details.

You should have received a copy of the GNU General Public License along with
this program.  If not, see <http://www.gnu.org/licenses/>.
"""

from imiptools.dates import get_datetime
from imiptools.freebusy.common import *
from imiptools.text import FileTable, FileTableDict, FileTableSingle
from imiptools.stores.file import Store

# Test free/busy collection.

fb = FreeBusyCollection(FileTable("testfb.tmp",
                                  in_converter=period_from_tuple(FreeBusyPeriod),
                                  out_converter=period_to_tuple))
fb.clear()

start = get_datetime("20170530T210700Z")
end = get_datetime("20170530T210900Z")
p1 = FreeBusyPeriod(start, end)
fb.insert_period(p1)

start = get_datetime("20170530T205600Z")
end = get_datetime("20170530T205800Z")
p2 = FreeBusyPeriod(start, end)
fb.insert_period(p2)

print list(fb)
fb.close()

fb = FreeBusyCollection(FileTable("testfb.tmp",
                                  in_converter=period_from_tuple(FreeBusyPeriod),
                                  out_converter=period_to_tuple))
print list(fb)

print "----"



# Test single value table.

values = FileTableSingle("testsv.tmp")
values.clear()

values.append("Hello")
values.insert(0, "world")

print list(values)
values.close()

values = FileTableSingle("testsv.tmp")
print list(values)

print "----"



# Test dictionary table.

limits = FileTableDict("testdt.tmp")
limits.clear()

limits["mailto:paul.boddie@example.com"] = "PT1H"

print list(limits)
limits.close()

limits = FileTableDict("testdt.tmp")
print list(limits)

print "----"



# Test store.

s = Store("store.tmp")

fb = s.get_freebusy("mailto:paul.boddie@example.com")
try:
    fb.insert_period(p1)
except TypeError:
    print "Free/busy collection not mutable, as expected."

fb = s.get_freebusy("mailto:paul.boddie@example.com", mutable=True)
fb.insert_period(p1)
fb.insert_period(p2)
s.set_freebusy("mailto:paul.boddie@example.com", fb)
s.set_freebusy("mailto:harvey.horse@example.com", fb)

print list(fb)

s = Store("store.tmp")

fb = s.get_freebusy("mailto:paul.boddie@example.com")
print list(fb)
fb = s.get_freebusy("mailto:harvey.horse@example.com")
print list(fb)



# Test store.

s = Store("store.tmp")

req = s.get_requests("mailto:paul.boddie@example.com")
req.clear()

req.append(("uid1@example.com", None, None))
req.append(("uid2@example.com", None, None))
req.append(("uid2@example.com", "20170531T140100Z", None))
req.append(("uid2@example.com", "20170531T140900Z", "COUNTER"))
s.set_requests("mailto:paul.boddie@example.com", req)
s.set_requests("mailto:harvey.horse@example.com", req)

print list(req)

s = Store("store.tmp")

req = s.get_requests("mailto:paul.boddie@example.com")
print list(req)
req = s.get_requests("mailto:harvey.horse@example.com")
print list(req)



# Test store.

s = Store("store.tmp")

fb = s.get_freebusy_for_other("mailto:paul.boddie@example.com", "mailto:harvey.horse@example.com", mutable=True)
fb.clear()
fb.insert_period(p1)
fb.insert_period(p2)
s.set_freebusy_for_other("mailto:paul.boddie@example.com", fb, "mailto:harvey.horse@example.com")

print list(fb)

s = Store("store.tmp")

fb = s.get_freebusy_for_other("mailto:paul.boddie@example.com", "mailto:harvey.horse@example.com")
print list(fb)

# vim: tabstop=4 expandtab shiftwidth=4
